##############################################################################################################
##############################################################################################################
###                                                                                                        ###
### Poor Emotion Regulation Ability Mediates the Link between Depressive Symptoms and Affective Bipolarity ###
###                                                                                                        ###
##############################################################################################################
##############################################################################################################

###### Full Reproducible R Code by Egon Dejonckheere #########################################################

#### Load required packages ##################################################################################

rm(list=ls())

require(foreign)
require(ggplot2)
require(psych)
require(mediation)
require(Hmisc)
require(gridExtra)
require(grid)

### Set working directory and load data ######################################################################

## Update working directory 

setwd("C:\\Users\\u0097348\\Desktop\\Dejonckheere et al (2018) - ESM data")
setwd("C:\\Users\\u0097348\\SyncFiles\\Personal\\PhD\\Research Project 8 (PA & NA)\\Writings\\Article 2\\Emotion")

## Load data

dat <- read.spss(file="Dejonckheere et al (2018) - ESM data.sav", to.data.frame = TRUE, use.value.labels = TRUE)

dat <- as.data.frame(dat)

### Calculate person means and SDs from ESM protocol #########################################################

dat$m.NA <- ave(dat$NA.,  dat$PID, FUN=function(x) mean(x, na.rm=TRUE))
dat$m.PA <- ave(dat$PA,   dat$PID, FUN=function(x) mean(x, na.rm=TRUE))

dat$sd.PA <- ave(dat$PA,  dat$PID, FUN=function(x)  sd(x, na.rm=TRUE))
dat$sd.NA <- ave(dat$NA., dat$PID, FUN=function(x)  sd(x, na.rm=TRUE))

### Calculate within-person PA-NA correlations ###############################################################

## Number of participants

ID <- unique(dat$PID)
length(ID)

# 100

## Within-person PA-NA correlation

cor.matrix <- matrix(nrow=length(ID), ncol = 2)

for (i in 1:length(ID)){
  cor.matrix[i,1] <- ID[i]
  dat.temp <- dat[which(dat$PID == ID[i]),] 
  cor.matrix[i,2] <-  cor(dat.temp$PA, dat.temp$NA., use ="pairwise.complete.obs", method = "pearson")
}

cor.matrix = as.data.frame(cor.matrix)
colnames(cor.matrix) <- c("PID", "PANAcor")

### Merge level 1 & level 2 ##################################################################################

dat2 <- dat[which(dat$Beepnum == 1),]
dat2 <- merge(dat2, cor.matrix, by = "PID")

### Calculate grand means and SDs - Table 1 ##################################################################

  mean(dat2$CESDmean, na.rm = TRUE)
    sd(dat2$CESDmean, na.rm = TRUE)

## 0.6205 (0.3919709)  

  mean(dat2$BDImean, na.rm = TRUE)
    sd(dat2$BDImean, na.rm = TRUE)

## 0.431 (0.366238)

       mean(dat2$ERA, na.rm = TRUE)
         sd(dat2$ERA, na.rm = TRUE)
         
## 4.204167 (1.108607)          
         
   mean(dat2$RRS_br,  na.rm = TRUE)
     sd(dat2$RRS_br,  na.rm = TRUE)
         
## 2.192 (0.6292018)  

      mean(dat2$m.PA, na.rm = TRUE)
        sd(dat2$m.PA, na.rm = TRUE)

## 62.36851 (11.08082)
 
      mean(dat2$m.NA, na.rm = TRUE)
        sd(dat2$m.NA, na.rm = TRUE)

## 15.99481 (9.222748)
   
     mean(dat2$sd.PA, na.rm = TRUE)
       sd(dat2$sd.PA, na.rm = TRUE)
 
## 18.14981 (4.664499)
  
     mean(dat2$sd.NA, na.rm = TRUE)
       sd(dat2$sd.NA, na.rm = TRUE)

## 13.32919 (4.424524)  

   mean(dat2$PANAcor, na.rm = TRUE)
     sd(dat2$PANAcor, na.rm = TRUE)

## -0.6144025 (0.1623836)    
     
### Calculate between-person correlations - Table 1 ##########################################################
     
correlations <- subset(dat2, select = c(CESDmean, BDImean, ERA, RRS_br, m.PA, m.NA, sd.PA, sd.NA, PANAcor))
correlations <- rcorr(as.matrix(correlations))
correlations     

#          CESDmean BDImean   ERA RRS_br  m.PA  m.NA sd.PA sd.NA PANAcor
# CESDmean     1.00    0.76 -0.53   0.42 -0.40  0.38  0.12  0.25   -0.22
# BDImean      0.76    1.00 -0.58   0.47 -0.32  0.38  0.23  0.38   -0.28
# ERA         -0.53   -0.58  1.00  -0.62  0.21 -0.28 -0.06 -0.31    0.31
# RRS_br       0.42    0.47 -0.62   1.00 -0.13  0.21  0.16  0.32   -0.21
# m.PA        -0.40   -0.32  0.21  -0.13  1.00 -0.59  0.05 -0.15   -0.05
# m.NA         0.38    0.38 -0.28   0.21 -0.59  1.00  0.16  0.53   -0.16
# sd.PA        0.12    0.23 -0.06   0.16  0.05  0.16  1.00  0.67   -0.22
# sd.NA        0.25    0.38 -0.31   0.32 -0.15  0.53  0.67  1.00   -0.29
# PANAcor     -0.22   -0.28  0.31  -0.21 -0.05 -0.16 -0.22 -0.29    1.00
# 
# n = 100 
# 
# P
#          CESDmean BDImean ERA    RRS_br m.PA   m.NA   sd.PA  sd.NA  PANAcor
# CESDmean          0.0000  0.0000 0.0000 0.0000 0.0000 0.2412 0.0110 0.0281 
# BDImean  0.0000           0.0000 0.0000 0.0013 0.0000 0.0230 0.0001 0.0044 
# ERA      0.0000   0.0000         0.0000 0.0328 0.0046 0.5864 0.0015 0.0017 
# RRS_br   0.0000   0.0000  0.0000        0.1874 0.0345 0.1093 0.0011 0.0333 
# m.PA     0.0000   0.0013  0.0328 0.1874        0.0000 0.6019 0.1418 0.6289 
# m.NA     0.0000   0.0000  0.0046 0.0345 0.0000        0.1013 0.0000 0.1144 
# sd.PA    0.2412   0.0230  0.5864 0.1093 0.6019 0.1013        0.0000 0.0312 
# sd.NA    0.0110   0.0001  0.0015 0.0011 0.1418 0.0000 0.0000        0.0032 
# PANAcor  0.0281   0.0044  0.0017 0.0333 0.6289 0.1144 0.0312 0.0032       

### Multiple regression predicting PA-NA correlation - Table 2 ###############################################

## CES-D as predictor

fit_PANAcor0 <- lm(PANAcor ~ CESDmean, data=dat2)
summary(fit_PANAcor0)

# Call:
#   lm(formula = PANAcor ~ CESDmean, data = dat2)
# 
# Residuals:
#   Min       1Q   Median       3Q      Max 
# -0.28621 -0.10784 -0.03623  0.06572  0.56597 
# 
# Coefficients:
#                Estimate Std. Error t value Pr(>|t|)    
# (Intercept)   -0.55792    0.02992  -18.65   <2e-16 ***
#   CESDmean    -0.09102    0.04083   -2.23   0.0281 *  
#   ---
#   Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1
# 
# Residual standard error: 0.1592 on 98 degrees of freedom
# Multiple R-squared:  0.04828,	Adjusted R-squared:  0.03857 
# F-statistic: 4.971 on 1 and 98 DF,  p-value: 0.02806

fit_PANAcor1 <- lm(PANAcor ~ CESDmean + m.PA + m.NA , data=dat2)
summary(fit_PANAcor1)

# Call:
#   lm(formula = PANAcor ~ CESDmean + m.PA + m.NA, data = dat2)
# 
# Residuals:
#   Min       1Q   Median       3Q      Max 
# -0.28523 -0.10189 -0.03358  0.07788  0.55303 
# 
# Coefficients:
#                Estimate Std. Error t value Pr(>|t|)  
#   (Intercept) -0.226888   0.141168  -1.607   0.1113  
#   CESDmean    -0.100356   0.044464  -2.257   0.0263 *
#   m.PA        -0.004157   0.001805  -2.303   0.0234 *
#   m.NA        -0.004127   0.002155  -1.915   0.0585 .
# ---
#   Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1
# 
# Residual standard error: 0.1561 on 96 degrees of freedom
# Multiple R-squared:  0.1043,	Adjusted R-squared:  0.07634 
# F-statistic: 3.727 on 3 and 96 DF,  p-value: 0.01389

fit_PANAcor2 <- lm(PANAcor ~ CESDmean + m.PA + m.NA + sd.NA + sd.PA, data=dat2)
summary(fit_PANAcor2)

# Call:
#   lm(formula = PANAcor ~ CESDmean + m.PA + m.NA + sd.NA + sd.PA, data = dat2)
# 
# Residuals:
#   Min       1Q   Median       3Q      Max 
# -0.29295 -0.10007 -0.03425  0.07491  0.52739 
# 
# Coefficients:
#              Estimate Std. Error t value Pr(>|t|)  
# (Intercept) -0.215137   0.144685  -1.487   0.1404  
# CESDmean    -0.089296   0.044467  -2.008   0.0475 *
# m.PA        -0.003219   0.001855  -1.735   0.0861 .
# m.NA        -0.001710   0.002585  -0.661   0.5100  
# sd.NA       -0.007307   0.005839  -1.251   0.2139  
# sd.PA       -0.001012   0.004712  -0.215   0.8304  
# ---
#   Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1
# 
# Residual standard error: 0.1547 on 94 degrees of freedom
# Multiple R-squared:  0.1379,	Adjusted R-squared:  0.09203 
# F-statistic: 3.007 on 5 and 94 DF,  p-value: 0.01459

## BDI-II as predictor

fit_PANAcor3 <- lm(PANAcor ~ BDImean, data=dat2)
summary(fit_PANAcor3)

# Call:
#   lm(formula = PANAcor ~ BDImean, data = dat2)
# 
# Residuals:
#   Min       1Q   Median       3Q      Max 
# -0.28480 -0.10290 -0.03251  0.06619  0.54576 
# 
# Coefficients:
#               Estimate Std. Error t value Pr(>|t|)    
#   (Intercept) -0.56047    0.02425 -23.111  < 2e-16 ***
#   BDImean     -0.12514    0.04297  -2.912  0.00444 ** 
#   ---
#   Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1
# 
# Residual standard error: 0.1566 on 98 degrees of freedom
# Multiple R-squared:  0.07965,	Adjusted R-squared:  0.07026 
# F-statistic: 8.482 on 1 and 98 DF,  p-value: 0.004443

fit_PANAcor4 <- lm(PANAcor ~ BDImean + m.PA + m.NA , data=dat2)
summary(fit_PANAcor4)

# Call:
#   lm(formula = PANAcor ~ BDImean + m.PA + m.NA, data = dat2)
# 
# Residuals:
#   Min       1Q   Median       3Q      Max 
# -0.28976 -0.10723 -0.02147  0.07997  0.53868 
# 
# Coefficients:
#                Estimate Std. Error t value Pr(>|t|)   
#   (Intercept) -0.264733   0.133966  -1.976  0.05101 . 
#   BDImean     -0.127123   0.046151  -2.754  0.00703 **
#   m.PA        -0.003811   0.001749  -2.179  0.03177 * 
#   m.NA        -0.003574   0.002159  -1.656  0.10103   
# ---
#   Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1
# 
# Residual standard error: 0.1542 on 96 degrees of freedom
# Multiple R-squared:  0.1259,	Adjusted R-squared:  0.09857 
# F-statistic: 4.608 on 3 and 96 DF,  p-value: 0.004675

fit_PANAcor5 <- lm(PANAcor ~ BDImean + m.PA + m.NA + sd.NA + sd.PA, data=dat2)
summary(fit_PANAcor5)

# Call:
#   lm(formula = PANAcor ~ BDImean + m.PA + m.NA + sd.NA + sd.PA, 
#      data = dat2)
# 
# Residuals:
#   Min       1Q   Median       3Q      Max 
# -0.28443 -0.10227 -0.02738  0.07843  0.52088 
# 
# Coefficients:
#               Estimate Std. Error t value Pr(>|t|)  
# (Intercept) -0.2557061  0.1386993  -1.844   0.0684 .
# BDImean     -0.1078342  0.0477637  -2.258   0.0263 *
# m.PA        -0.0030395  0.0018174  -1.672   0.0978 .
# m.NA        -0.0017423  0.0025673  -0.679   0.4990  
# sd.NA       -0.0059679  0.0058732  -1.016   0.3122  
# sd.PA       -0.0008396  0.0046884  -0.179   0.8583  
# ---
#   Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1
# 
# Residual standard error: 0.1539 on 94 degrees of freedom
# Multiple R-squared:  0.1472,	Adjusted R-squared:  0.1018 
# F-statistic: 3.244 on 5 and 94 DF,  p-value: 0.009556

## ERA as predictor

fit_PANAcor6 <- lm(PANAcor ~ ERA, data=dat2)
summary(fit_PANAcor6)

# Call:
#   lm(formula = PANAcor ~ ERA, data = dat2)
# 
# Residuals:
#   Min       1Q   Median       3Q      Max 
# -0.28505 -0.10772 -0.01814  0.06773  0.56380 
# 
# Coefficients:
#                Estimate Std. Error t value Pr(>|t|)    
#   (Intercept) -0.80509    0.06115 -13.166  < 2e-16 ***
#   ERA          0.04536    0.01407   3.224  0.00172 ** 
#   ---
#   Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1
# 
# Residual standard error: 0.1552 on 98 degrees of freedom
# Multiple R-squared:  0.09588,	Adjusted R-squared:  0.08666 
# F-statistic: 10.39 on 1 and 98 DF,  p-value: 0.001719

fit_PANAcor7 <- lm(PANAcor ~ ERA + m.PA + m.NA , data=dat2)
summary(fit_PANAcor7)

# Call:
#   lm(formula = PANAcor ~ ERA + m.PA + m.NA, data = dat2)
# 
# Residuals:
#   Min       1Q   Median       3Q      Max 
# -0.31800 -0.10483 -0.02338  0.06300  0.52395 
# 
# Coefficients:
#                Estimate Std. Error t value Pr(>|t|)    
#   (Intercept) -0.516306   0.144275  -3.579 0.000544 ***
#   ERA          0.043951   0.014479   3.036 0.003090 ** 
#   m.PA        -0.003551   0.001726  -2.057 0.042389 *  
#   m.NA        -0.003840   0.002111  -1.819 0.072074 .  
# ---
#   Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1
# 
# Residual standard error: 0.153 on 96 degrees of freedom
# Multiple R-squared:  0.1394,	Adjusted R-squared:  0.1125 
# F-statistic: 5.184 on 3 and 96 DF,  p-value: 0.002312

fit_PANAcor8 <- lm(PANAcor ~ ERA + m.PA + m.NA + sd.NA + sd.PA, data=dat2)
summary(fit_PANAcor8)

# Call:
#   lm(formula = PANAcor ~ ERA + m.PA + m.NA + sd.NA + sd.PA, data = dat2)
# 
# Residuals:
#   Min       1Q   Median       3Q      Max 
# -0.29693 -0.10164 -0.02672  0.05783  0.49359 
# 
# Coefficients:
#                 Estimate Std. Error t value Pr(>|t|)   
#   (Intercept) -0.461856   0.147430  -3.133  0.00231 **
#   ERA          0.040920   0.015034   2.722  0.00774 **
#   m.PA        -0.002817   0.001777  -1.586  0.11615   
#   m.NA        -0.002229   0.002528  -0.882  0.38009   
#   sd.NA       -0.003508   0.005976  -0.587  0.55864   
#   sd.PA       -0.003662   0.004712  -0.777  0.43905   
# ---
#   Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1
# 
# Residual standard error: 0.1521 on 94 degrees of freedom
# Multiple R-squared:  0.1666,	Adjusted R-squared:  0.1223 
# F-statistic: 3.758 on 5 and 94 DF,  p-value: 0.003805

## RRS (brooding) as predictor

fit_PANAcor9 <- lm(PANAcor ~ RRS_br, data=dat2)
summary(fit_PANAcor9)

# Call:
#   lm(formula = PANAcor ~ RRS_br, data = dat2)
# 
# Residuals:
#   Min       1Q   Median       3Q      Max 
# -0.26494 -0.11185 -0.04251  0.06329  0.53414 
# 
# Coefficients:
#              Estimate Std. Error t value Pr(>|t|)    
# (Intercept) -0.49385    0.05807  -8.505  2.1e-13 ***
#   RRS_br    -0.05500    0.02547  -2.159   0.0333 *  
#   ---
#   Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1
# 
# Residual standard error: 0.1595 on 98 degrees of freedom
# Multiple R-squared:  0.04541,	Adjusted R-squared:  0.03567 
# F-statistic: 4.662 on 1 and 98 DF,  p-value: 0.03327

fit_PANAcor10 <- lm(PANAcor ~ RRS_br + m.PA + m.NA , data=dat2)
summary(fit_PANAcor10)

# Call:
#   lm(formula = PANAcor ~ RRS_br + m.PA + m.NA, data = dat2)
# 
# Residuals:
#   Min       1Q   Median       3Q      Max 
# -0.27302 -0.11643 -0.02740  0.07097  0.52011 
# 
# Coefficients:
#              Estimate Std. Error t value Pr(>|t|)  
# (Intercept) -0.232881   0.143941  -1.618   0.1090  
# RRS_br      -0.048938   0.025695  -1.905   0.0598 .
# m.PA        -0.003265   0.001771  -1.844   0.0683 .
# m.NA        -0.004415   0.002157  -2.047   0.0434 *
#   ---
#   Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1
# 
# Residual standard error: 0.1572 on 96 degrees of freedom
# Multiple R-squared:  0.09114,	Adjusted R-squared:  0.06274 
# F-statistic: 3.209 on 3 and 96 DF,  p-value: 0.02649

fit_PANAcor11 <- lm(PANAcor ~ RRS_br + m.PA + m.NA + sd.NA + sd.PA, data=dat2)
summary(fit_PANAcor11)

# Call:
#   lm(formula = PANAcor ~ RRS_br + m.PA + m.NA + sd.NA + sd.PA, 
#      data = dat2)
# 
# Residuals:
#   Min       1Q   Median       3Q      Max 
# -0.27103 -0.10224 -0.03825  0.08722  0.50277 
# 
# Coefficients:
#               Estimate Std. Error t value Pr(>|t|)
# (Intercept) -0.227759   0.149208  -1.526    0.130
# RRS_br      -0.037605   0.026548  -1.416    0.160
# m.PA        -0.002470   0.001820  -1.358    0.178
# m.NA        -0.002320   0.002599  -0.893    0.374
# sd.NA       -0.006140   0.006056  -1.014    0.313
# sd.PA       -0.001720   0.004769  -0.361    0.719
# 
# Residual standard error: 0.1564 on 94 degrees of freedom
# Multiple R-squared:  0.1197,	Adjusted R-squared:  0.07287 
# F-statistic: 2.556 on 5 and 94 DF,  p-value: 0.03251

### Mediation analysis: CES-D & BDI-II -> ERA -> Affective Bipolarity ########################################

dat2$z.BDImean  <- (dat2$BDImean-mean(dat2$BDImean))/sd(dat2$BDImean)
dat2$z.CESDmean <- (dat2$CESDmean-mean(dat2$CESDmean))/sd(dat2$CESDmean)

dat2$z.ERA      <- (dat2$ERA-mean(dat2$ERA))/sd(dat2$ERA)
dat2$z.RRS_br   <- (dat2$RRS_br-mean(dat2$RRS_br))/sd(dat2$RRS_br)

dat2$z.PANAcor  <- (dat2$PANAcor-mean(dat2$PANAcor))/sd(dat2$PANAcor)

## Note that small deviations in estimated coeffiencts may occur due to the bootstrapping procedure.

## CES-D

A <- lm(z.ERA     ~ 0 + z.CESDmean         , data=dat2)
B <- lm(z.PANAcor ~ 0 + z.ERA              , data=dat2)
C <- lm(z.PANAcor ~ 0 + z.CESDmean         , data=dat2)
C.<- lm(z.PANAcor ~ 0 + z.CESDmean + z.ERA , data=dat2)

summary(A)$coefficients

#              Estimate Std. Error   t value     Pr(>|t|)
# z.CESDmean -0.5347803  0.0849248 -6.297104 8.376464e-09

summary(B)$coefficients

#       Estimate Std. Error   t value     Pr(>|t|)
# z.ERA 0.3096491 0.09556411 3.240224 0.001626983

summary(C)$coefficients

#           Estimate Std. Error   t value     Pr(>|t|)
# z.CESDmean -0.2197202 0.09804776 -2.240951 0.0272632

summary(C.)$coefficients

#              Estimate Std. Error   t value     Pr(>|t|)
# z.CESDmean -0.0758056  0.1134121 -0.6684082 0.50544440
# z.ERA       0.2691098  0.1134121  2.3728483 0.01960335

med.fit1 <- lm(z.ERA      ~ z.CESDmean, data=dat2)
out.fit1 <- lm(z.PANAcor  ~ z.CESDmean + z.ERA, data=dat2)

med.out1 <- mediate(med.fit1, out.fit1, treat = "z.CESDmean", mediator = "z.ERA", sims = 10000, boot = TRUE)
summary(med.out1)

# Causal Mediation Analysis 
# 
# Nonparametric Bootstrap Confidence Intervals with the Percentile Method
# 
#                Estimate 95% CI Lower 95% CI Upper p-value
# ACME            -0.1439      -0.2799      -0.0349    0.01
# ADE             -0.0758      -0.2749       0.1611    0.48
# Total Effect    -0.2197      -0.3940      -0.0232    0.03
# Prop. Mediated   0.6550       0.0582       3.3727    0.04
# 
# Sample Size Used: 100 
# 
# 
# Simulations: 10000 

## BDI-II

A <- lm(z.ERA     ~ 0 + z.BDImean         , data=dat2)
B <- lm(z.PANAcor ~ 0 + z.ERA             , data=dat2)
C <- lm(z.PANAcor ~ 0 + z.BDImean         , data=dat2)
C.<- lm(z.PANAcor ~ 0 + z.BDImean + z.ERA , data=dat2)

summary(A)$coefficients

#              Estimate Std. Error   t value     Pr(>|t|)
# z.BDImean -0.5809022  0.0818074 -7.100851 1.910993e-10

summary(B)$coefficients

#        Estimate Std. Error  t value    Pr(>|t|)
# z.ERA 0.3096491 0.09556411 3.240224 0.001626983

summary(C)$coefficients

#            Estimate Std. Error   t value    Pr(>|t|)
# z.BDImean -0.28223 0.09641798 -2.927152 0.004243839

summary(C.)$coefficients

#              Estimate Std. Error   t value   Pr(>|t|)
# z.BDImean -0.1544846  0.1169655 -1.320771 0.18965385
# z.ERA       0.2199087  0.1169655  1.880115 0.06306238

med.fit2 <- lm(z.ERA      ~ z.BDImean, data=dat2)
out.fit2 <- lm(z.PANAcor  ~ z.BDImean + z.ERA, data=dat2)

med.out2 <- mediate(med.fit2, out.fit2, treat = "z.BDImean", mediator = "z.ERA", sims = 10000, boot = TRUE)
summary(med.out2)

# Causal Mediation Analysis 
# 
# Nonparametric Bootstrap Confidence Intervals with the Percentile Method
# 
#                Estimate 95% CI Lower 95% CI Upper p-value
# ACME           -0.12775     -0.25220     -0.00505    0.04
# ADE            -0.15448     -0.36597      0.03139    0.10
# Total Effect   -0.28223     -0.45285     -0.12379    0.00
# Prop. Mediated  0.45263      0.01539      1.18738    0.04
# 
# Sample Size Used: 100 
# 
# 
# Simulations: 10000 

### Mediation analysis: CES-D & BDI-II -> RRS_br -> Affective Bipolarity #####################################

## CES-D

A <- lm(z.RRS_br  ~ 0 + z.CESDmean            , data=dat2)
B <- lm(z.PANAcor ~ 0 + z.RRS_br              , data=dat2)
C <- lm(z.PANAcor ~ 0 + z.CESDmean            , data=dat2)
C.<- lm(z.PANAcor ~ 0 + z.CESDmean + z.RRS_br , data=dat2)

summary(A)$coefficients

#             Estimate Std. Error  t value     Pr(>|t|)
# z.CESDmean 0.4200645  0.0912066 4.605637 1.224806e-05

summary(B)$coefficients

#            Estimate Std. Error   t value   Pr(>|t|)
# z.RRS_br -0.2131068  0.0981951 -2.170238 0.03238049

summary(C)$coefficients

#              Estimate Std. Error   t value  Pr(>|t|)
# z.CESDmean -0.2197202 0.09804776 -2.240951 0.0272632

summary(C.)$coefficients

#              Estimate Std. Error   t value  Pr(>|t|)
# z.CESDmean -0.1580988  0.1075763 -1.469643 0.1448615
# z.RRS_br   -0.1466951  0.1075763 -1.363637 0.1758060

med.fit3 <- lm(z.RRS_br   ~ z.CESDmean, data=dat2)
out.fit3 <- lm(z.PANAcor  ~ z.CESDmean + z.RRS_br, data=dat2)

med.out3 <- mediate(med.fit3, out.fit3, treat = "z.CESDmean", mediator = "z.RRS_br", sims = 10000, boot = TRUE)
summary(med.out3)

# Causal Mediation Analysis 
# 
# Nonparametric Bootstrap Confidence Intervals with the Percentile Method
# 
#                Estimate 95% CI Lower 95% CI Upper p-value
# ACME            -0.0616      -0.1841       0.0178    0.16
# ADE             -0.1581      -0.3312       0.0547    0.13
# Total Effect    -0.2197      -0.3936      -0.0262    0.03
# Prop. Mediated   0.2805      -0.1858       1.4356    0.18
# 
# Sample Size Used: 100 
# 
# 
# Simulations: 10000 

## BDI-II

A <- lm(z.RRS_br  ~ 0 + z.BDImean            , data=dat2)
B <- lm(z.PANAcor ~ 0 + z.RRS_br             , data=dat2)
C <- lm(z.PANAcor ~ 0 + z.BDImean            , data=dat2)
C.<- lm(z.PANAcor ~ 0 + z.BDImean + z.RRS_br , data=dat2)

summary(A)$coefficients

#             Estimate Std. Error  t value     Pr(>|t|)
# z.BDImean 0.4736179 0.08851674 5.350603 5.665831e-07

summary(B)$coefficients

#            Estimate Std. Error   t value   Pr(>|t|)
# z.RRS_br -0.2131068  0.0981951 -2.170238 0.03238049

summary(C)$coefficients

#            Estimate Std. Error   t value    Pr(>|t|)
# z.BDImean -0.28223 0.09641798 -2.927152 0.004243839

summary(C.)$coefficients

#              Estimate Std. Error    t value  Pr(>|t|)
# z.BDImean -0.2337271  0.1095448 -2.1336219 0.0353702
# z.RRS_br   -0.1024094  0.1095448 -0.9348639 0.3521563

med.fit4 <- lm(z.RRS_br   ~ z.BDImean, data=dat2)
out.fit4 <- lm(z.PANAcor  ~ z.BDImean + z.RRS_br, data=dat2)

med.out4 <- mediate(med.fit4, out.fit4, treat = "z.BDImean", mediator = "z.RRS_br", sims = 10000, boot = TRUE)
summary(med.out4)

# Causal Mediation Analysis 
# 
# Nonparametric Bootstrap Confidence Intervals with the Percentile Method
# 
#                Estimate 95% CI Lower 95% CI Upper p-value
# ACME            -0.0485      -0.1716       0.0416    0.33
# ADE             -0.2337      -0.4029      -0.0699    0.00
# Total Effect    -0.2822      -0.4618      -0.1227    0.00
# Prop. Mediated   0.1719      -0.1925       0.6136    0.33
# 
# Sample Size Used: 100 
# 
# 
# Simulations: 10000 

### Multiverse Analysis - Figure #############################################################################

## Load PA and NA as Matrix

PAA=as.matrix(dat[,c("Happy","Relaxed")])
NAA=as.matrix(dat[,c("Sad","Anger", "Stress")])

## Compute all possible combinations for PA and NA given [x] elements

PN=lapply(1:dim(PAA)[2], function(x) combn(dim(PAA)[2],x))
NN=lapply(1:dim(NAA)[2], function(x) combn(dim(NAA)[2],x))

## Total amount of correlations

NTODO=(2^dim(PAA)[2]-1)*(2^dim(NAA)[2]-1)
NTODO

# 21

## Make default matrix with 0's to fill out

DOALLPA=matrix(0,ncol=dim(PAA)[2],nrow=NTODO)
DOALLNA=matrix(0,ncol=dim(NAA)[2],nrow=NTODO)

## Change default matrix with appropriate 1's to make all possible PA and NA composites

add=1
for (i1 in 1:length(PN)){
  for (i2 in 1:dim(PN[[i1]])[2]){
    takePA=PN[[i1]][,i2]
    for (j1 in 1:length(NN)){
      for (j2 in 1:dim(NN[[j1]])[2]){
        takeNA=NN[[j1]][,j2]
        
        DOALLPA[add,takePA]=1
        DOALLNA[add,takeNA]=1
        add=add+1
      }
    }
  }
}

## Compute all PA & NA means for all possible combinations and calculate correlations between them

PID = unique(dat$PID)
corM <- matrix(0,nrow=length(PID),ncol=NTODO)

for( i in 1:dim(DOALLPA)[1]){
  takePA=which(DOALLPA[i,]==1)
  takeNA=which(DOALLNA[i,]==1)
  
  if (length(takePA)>1)
  {PAtemp=rowMeans(PAA[,takePA], na.rm = TRUE)}
  else{PAtemp=PAA[,takePA]}
  
  if (length(takeNA)>1)
  {NAtemp=rowMeans(NAA[,takeNA], na.rm = TRUE)}
  else{NAtemp=NAA[,takeNA]}
  
  for (j in 1:length(PID)){
    idxUse=which(dat$PID == PID[j])
    corM[j,i] <- cor(PAtemp[idxUse], NAtemp[idxUse],use ="pairwise.complete.obs", method = "pearson")
  }
  
}

## Relate all possible PA-NA correlations with combined measure of CES-D and BDI-II (standardized)

dat2$depr <- ((dat2$z.CESDmean + dat2$z.BDImean)/2)

dat  <- merge(dat, dat2, by="PID")

cTempA=c()
pTempA=c()

for(i in 1:NTODO){
  temp=cor.test(dat2$depr, corM[,i], method = "pearson", na.action=na.omit)
  cTempA[i]=temp$estimate
  pTempA[i]=temp$p.value
}

cTempA=as.matrix(cTempA, nrow=length(PID),ncol=1)
sort(round(cTempA,3))

# -0.327 -0.326 -0.326 -0.316 -0.300 -0.292 -0.286
# -0.274 -0.271 -0.268 -0.259 -0.255 -0.224 -0.210 
# -0.206 -0.204 -0.199 -0.194 -0.101 -0.100 -0.092


pTempA=as.matrix(pTempA, nrow=length(PID),ncol=1)
sort(round(pTempA,3))

# 0.001 0.001 0.001 0.001 0.002 0.003 0.004 0.006 
# 0.006 0.007 0.009 0.010 0.025 0.036 0.040 0.041 
# 0.048 0.054 0.318 0.321 0.362

length(subset(pTempA, pTempA[] > 0.05))

# 4 

## Relate all possible PA-NA correlations with Emotion Regulation Ability

cTempB=c()
pTempB=c()

for(i in 1:NTODO){
  temp=cor.test(dat2$ERA, corM[,i], method = "pearson", na.action=na.omit)
  cTempB[i]=temp$estimate
  pTempB[i]=temp$p.value
}

cTempB=as.matrix(cTempB, nrow=length(PID),ncol=1)
sort(round(cTempB,3))

# 0.103 0.107 0.116 0.146 0.161 0.164 0.174 0.178 
# 0.179 0.179 0.207 0.224 0.235 0.277 0.287 0.290 
# 0.310 0.334 0.338 0.350 0.368

pTempB=as.matrix(pTempB, nrow=length(PID),ncol=1)
sort(round(pTempB,3))

# 0.000 0.000 0.001 0.001 0.002 0.003 0.004 0.005
# 0.019 0.025 0.039 0.074 0.074 0.076 0.084 0.103 
# 0.109 0.148 0.249 0.288 0.309

length(subset(pTempB, pTempB[] > 0.05))

# 10

## Relate all possible PA-NA correlations with Brooding

cTempC=c()
pTempC=c()

for(i in 1:NTODO){
  temp=cor.test(dat2$RRS_br, corM[,i], method = "pearson", na.action=na.omit)
  cTempC[i]=temp$estimate
  pTempC[i]=temp$p.value
}

cTempC=as.matrix(cTempC, nrow=length(PID),ncol=1)
sort(round(cTempC,3))

# -0.238 -0.225 -0.224 -0.218 -0.213 -0.201 -0.201
# -0.191 -0.190 -0.180 -0.169 -0.156 -0.148 -0.141 
# -0.132 -0.122 -0.110 -0.106 -0.089 -0.088 -0.064

pTempC=as.matrix(pTempC, nrow=length(PID),ncol=1)
sort(round(pTempC,3))

# 0.017 0.025 0.025 0.029 0.033 0.045 0.045 0.058 
# 0.058 0.073 0.093 0.122 0.140 0.163 0.190 0.227
# 0.275 0.292 0.381 0.385 0.529

length(subset(pTempC, pTempC[] > 0.05))

# 14

## Make graph for Appendix Figure - Panel A 

numformat <- function(x, digits = 2) { 
  ncode <- paste0("%.", digits, "f")
  sub("^(-?)0.", "\\1.", sprintf(ncode, x))
}

cat1 <- rep(c(1:7), 3)
cat2 <- rep(1:3, each = 7)

dfA <- data.frame(category1 = cat1, category2 = cat2, value = (as.vector(pTempA)))
dfA[["sign"]] = ifelse(dfA[["value"]] <= 0.05, "significant", "nonsignificant")

Panel_A <- ggplot(dfA, aes(x = category1, y = category2, fill = sign)) +
  geom_tile(colour = "black") +
  geom_text(label = numformat((dfA$value), 3), size = 3, colour = "black") + 
  geom_segment(aes(y = 1, x = 0.25, yend = 1, xend = 0.5)) + 
  geom_segment(aes(y = 2, x = 0.25, yend = 2, xend = 0.5)) + 
  geom_segment(aes(y = 3, x = 0.25, yend = 3, xend = 0.5)) + 
  geom_segment(aes(y = 3.5, x = 1, yend = 3.75, xend = 1)) + 
  geom_segment(aes(y = 3.5, x = 2, yend = 3.75, xend = 2)) + 
  geom_segment(aes(y = 3.5, x = 3, yend = 3.75, xend = 3)) + 
  geom_segment(aes(y = 3.5, x = 4, yend = 3.75, xend = 4)) + 
  geom_segment(aes(y = 3.5, x = 5, yend = 3.75, xend = 5)) + 
  geom_segment(aes(y = 3.5, x = 6, yend = 3.75, xend = 6)) + 
  geom_segment(aes(y = 3.5, x = 7, yend = 3.75, xend = 7)) + 
  annotate("text", x = 0, y = 1:3, label = c("HA", "RE", "RE"), size = 3) +
  annotate("text", x = -0.60, y = 1:3, label = c("", "", "HA"), size = 3) +
  annotate("text", x = 1:7, y = 4, label = c("SA", "AN", "ST", "SA", "SA", "AN", "SA"), size = 3) + 
  annotate("text", x = 1:7, y = 4.35, label = c("", "", "", "AN", "ST", "ST", "AN"), size = 3) + 
  annotate("text", x = 1:7, y = 4.70, label = c("", "", "", "", "", "", "ST"), size = 3) + 
  scale_fill_manual(values = c(significant = "grey", nonsignificant = "white")) + 
  scale_x_discrete(expand = c(0.10, 0)) + scale_y_reverse()  + 
  theme(panel.grid.minor = element_blank()) + theme(panel.grid.major = element_blank()) + 
  theme(axis.ticks = element_blank(), axis.text.x = element_blank(), axis.text.y = element_blank()) + theme(panel.background = element_rect(fill = "transparent")) + 
  theme(legend.position = "none") + theme() + xlab("") + ylab("") + ggtitle("    A. Depressive Symptoms")

## Make graph for Appendix Figure - Panel B 

cat1 <- rep(c(1:7), 3)
cat2 <- rep(1:3, each = 7)

dfB <- data.frame(category1 = cat1, category2 = cat2, value = (as.vector(pTempB)))
dfB[["sign"]] = ifelse(dfB[["value"]] <= 0.05, "significant", "nonsignificant")

Panel_B <- ggplot(dfB, aes(x = category1, y = category2, fill = sign)) +
  geom_tile(colour = "black") +
  geom_text(label = numformat((dfB$value), 3), size = 3, colour = "black") + 
  geom_segment(aes(y = 1, x = 0.25, yend = 1, xend = 0.5)) + 
  geom_segment(aes(y = 2, x = 0.25, yend = 2, xend = 0.5)) + 
  geom_segment(aes(y = 3, x = 0.25, yend = 3, xend = 0.5)) + 
  geom_segment(aes(y = 3.5, x = 1, yend = 3.75, xend = 1)) + 
  geom_segment(aes(y = 3.5, x = 2, yend = 3.75, xend = 2)) + 
  geom_segment(aes(y = 3.5, x = 3, yend = 3.75, xend = 3)) + 
  geom_segment(aes(y = 3.5, x = 4, yend = 3.75, xend = 4)) + 
  geom_segment(aes(y = 3.5, x = 5, yend = 3.75, xend = 5)) + 
  geom_segment(aes(y = 3.5, x = 6, yend = 3.75, xend = 6)) + 
  geom_segment(aes(y = 3.5, x = 7, yend = 3.75, xend = 7)) + 
  annotate("text", x = 0, y = 1:3, label = c("HA", "RE", "RE"), size = 3) +
  annotate("text", x = -0.60, y = 1:3, label = c("", "", "HA"), size = 3) +
  annotate("text", x = 1:7, y = 4, label = c("SA", "AN", "ST", "SA", "SA", "AN", "SA"), size = 3) + 
  annotate("text", x = 1:7, y = 4.35, label = c("", "", "", "AN", "ST", "ST", "AN"), size = 3) + 
  annotate("text", x = 1:7, y = 4.70, label = c("", "", "", "", "", "", "ST"), size = 3) + 
  scale_fill_manual(values = c(significant = "grey", nonsignificant = "white")) + 
  scale_x_discrete(expand = c(0.10, 0)) + scale_y_reverse()  + 
  theme(panel.grid.minor = element_blank()) + theme(panel.grid.major = element_blank()) + 
  theme(axis.ticks = element_blank(), axis.text.x = element_blank(), axis.text.y = element_blank()) + theme(panel.background = element_rect(fill = "transparent")) + 
  theme(legend.position = "none") + theme() + xlab("") + ylab("") + ggtitle("    B. Emotion Regulation Ability")
 
## Make graph for Appendix Figure - Panel C 

cat1 <- rep(c(1:7), 3)
cat2 <- rep(1:3, each = 7)

dfC <- data.frame(category1 = cat1, category2 = cat2, value = (as.vector(pTempC)))
dfC[["sign"]] = ifelse(dfC[["value"]] <= 0.05, "significant", "nonsignificant")

Panel_C <- ggplot(dfC, aes(x = category1, y = category2, fill = sign)) +
  geom_tile(colour = "black") +
  geom_text(label = numformat((dfC$value), 3), size = 3, colour = "black") + 
  geom_segment(aes(y = 1, x = 0.25, yend = 1, xend = 0.5)) + 
  geom_segment(aes(y = 2, x = 0.25, yend = 2, xend = 0.5)) + 
  geom_segment(aes(y = 3, x = 0.25, yend = 3, xend = 0.5)) + 
  geom_segment(aes(y = 3.5, x = 1, yend = 3.75, xend = 1)) + 
  geom_segment(aes(y = 3.5, x = 2, yend = 3.75, xend = 2)) + 
  geom_segment(aes(y = 3.5, x = 3, yend = 3.75, xend = 3)) + 
  geom_segment(aes(y = 3.5, x = 4, yend = 3.75, xend = 4)) + 
  geom_segment(aes(y = 3.5, x = 5, yend = 3.75, xend = 5)) + 
  geom_segment(aes(y = 3.5, x = 6, yend = 3.75, xend = 6)) + 
  geom_segment(aes(y = 3.5, x = 7, yend = 3.75, xend = 7)) + 
  annotate("text", x = 0, y = 1:3, label = c("HA", "RE", "RE"), size = 3) +
  annotate("text", x = -0.60, y = 1:3, label = c("", "", "HA"), size = 3) +
  annotate("text", x = 1:7, y = 4, label = c("SA", "AN", "ST", "SA", "SA", "AN", "SA"), size = 3) + 
  annotate("text", x = 1:7, y = 4.35, label = c("", "", "", "AN", "ST", "ST", "AN"), size = 3) + 
  annotate("text", x = 1:7, y = 4.70, label = c("", "", "", "", "", "", "ST"), size = 3) + 
  scale_fill_manual(values = c(significant = "grey", nonsignificant = "white")) + 
  scale_x_discrete(expand = c(0.10, 0)) + scale_y_reverse()  + 
  theme(panel.grid.minor = element_blank()) + theme(panel.grid.major = element_blank()) + 
  theme(axis.ticks = element_blank(), axis.text.x = element_blank(), axis.text.y = element_blank()) + theme(panel.background = element_rect(fill = "transparent")) + 
  theme(legend.position = "none") + theme() + xlab("") + ylab("") + ggtitle("    C. Rumination (brooding)")

print(grid.arrange(Panel_A, Panel_B, Panel_C, nrow=3, ncol=1))

